@@ -1,19 +1,24 @@
 """
 This module contains view actions for objects related to POIs.
 """
+import json
 import logging
 
+from django.conf import settings
 from django.contrib import messages
-from django.http import Http404
+from django.http import Http404, HttpResponse, JsonResponse
 from django.shortcuts import render, redirect
 from django.utils.translation import ugettext as _
 from django.views.decorators.http import require_POST
 
 from linkcheck.models import Link
 
+from ....api.decorators import json_response
 from ...decorators import permission_required
 from ...models import POI
 
+from ....nominatim_api.nominatim_api_client import NominatimApiClient
+
 logger = logging.getLogger(__name__)
 
 
@@ -24,7 +29,7 @@ def archive_poi(request, poi_id, region_slug, language_slug):
     Archive POI object
 
     :param request: The current request
-    :type request: ~django.http.HttpResponse
+    :type request: ~django.http.HttpRequest
 
     :param poi_id: The id of the POI which should be archived
     :type poi_id: int
@@ -65,7 +70,7 @@ def restore_poi(request, poi_id, region_slug, language_slug):
     Restore POI object (set ``archived=False``)
 
     :param request: The current request
-    :type request: ~django.http.HttpResponse
+    :type request: ~django.http.HttpRequest
 
     :param poi_id: The id of the POI which should be restored
     :type poi_id: int
@@ -108,7 +113,7 @@ def delete_poi(request, poi_id, region_slug, language_slug):
     Delete POI object
 
     :param request: The current request
-    :type request: ~django.http.HttpResponse
+    :type request: ~django.http.HttpRequest
 
     :param poi_id: The id of the POI which should be deleted
     :type poi_id: int
@@ -144,7 +149,7 @@ def view_poi(request, poi_id, region_slug, language_slug):
     View POI object
 
     :param request: The current request
-    :type request: ~django.http.HttpResponse
+    :type request: ~django.http.HttpRequest
 
     :param poi_id: The id of the POI which should be viewed
     :type poi_id: int
@@ -170,3 +175,51 @@ def view_poi(request, poi_id, region_slug, language_slug):
         raise Http404
 
     return render(request, template_name, {"poi_translation": poi_translation})
+
+
+@json_response
+@require_POST
+@permission_required("cms.view_poi")
+def auto_complete_address(request):
+    """
+    Autocomplete location address and coordinates
+
+    :param request: The current request
+    :type request: ~django.http.HttpRequest
+
+    :raises ~django.http.Http404: If no location was found for the given address
+
+    :return: The address and coordinates of the location
+    :rtype: ~django.http.JsonResponse
+    """
+    data = json.loads(request.body.decode("utf-8"))
+
+    if not settings.NOMINATIM_API_ENABLED:
+        return HttpResponse(_("Location service is disabled"), status_code=503)
+
+    street_input = data.get("street")
+    postcode_input = data.get("postcode")
+    city_input = data.get("city")
+
+    nominatim_api_client = NominatimApiClient()
+
+    result = nominatim_api_client.search(
+        street=street_input,
+        postalcode=postcode_input,
+        city=city_input,
+        addressdetails=True,
+    )
+
+    if not result:
+        raise Http404(_("Address could not be found"))
+
+    address = result.raw.get("address", {})
+    return JsonResponse(
+        data={
+            "postcode": address.get("postcode"),
+            "city": address.get("city"),
+            "country": address.get("country"),
+            "longitude": result.longitude,
+            "latitude": result.latitude,
+        }
+    )
