@@ -27,7 +27,7 @@ class UserSettingsView(TemplateView):
         :class:`~integreat_cms.cms.forms.users.user_password_form.UserPasswordForm`
 
         :param request: The current request
-        :type request: ~django.http.HttpResponse
+        :type request: ~django.http.HttpRequest
 
         :param \*args: The supplied arguments
         :type \*args: list
@@ -61,7 +61,7 @@ class UserSettingsView(TemplateView):
         object
 
         :param request: The current request
-        :type request: ~django.http.HttpResponse
+        :type request: ~django.http.HttpRequest
 
         :param \*args: The supplied arguments
         :type \*args: list
